summaryrefslogtreecommitdiff
path: root/apps/nshlib/nsh_parse.c
diff options
context:
space:
mode:
authorpatacongo <patacongo@42af7a65-404d-4744-a932-0658087f49c3>2012-12-23 20:22:41 +0000
committerpatacongo <patacongo@42af7a65-404d-4744-a932-0658087f49c3>2012-12-23 20:22:41 +0000
commit11e331a9ca6df348e97e57948fed9d23b9bba2ef (patch)
tree7e8992a85b852eb05e28b979c22698f10c456e14 /apps/nshlib/nsh_parse.c
parent99b4705b554f71a05f8924d92a5b8013bc6ca70e (diff)
downloadnuttx-11e331a9ca6df348e97e57948fed9d23b9bba2ef.tar.gz
nuttx-11e331a9ca6df348e97e57948fed9d23b9bba2ef.tar.bz2
nuttx-11e331a9ca6df348e97e57948fed9d23b9bba2ef.zip
Rename namedapp as simply builtin
git-svn-id: svn://svn.code.sf.net/p/nuttx/code/trunk@5454 42af7a65-404d-4744-a932-0658087f49c3
Diffstat (limited to 'apps/nshlib/nsh_parse.c')
-rw-r--r--apps/nshlib/nsh_parse.c8
1 files changed, 4 insertions, 4 deletions
diff --git a/apps/nshlib/nsh_parse.c b/apps/nshlib/nsh_parse.c
index 27068acff..70fa39f62 100644
--- a/apps/nshlib/nsh_parse.c
+++ b/apps/nshlib/nsh_parse.c
@@ -605,7 +605,7 @@ static inline void help_builtins(FAR struct nsh_vtbl_s *vtbl)
/* List the set of available built-in commands */
nsh_output(vtbl, "\nBuiltin Apps:\n");
- for (i = 0; (name = namedapp_getname(i)) != NULL; i++)
+ for (i = 0; (name = builtin_getname(i)) != NULL; i++)
{
nsh_output(vtbl, " %s\n", name);
}
@@ -726,7 +726,7 @@ static int cmd_exit(FAR struct nsh_vtbl_s *vtbl, int argc, char **argv)
* Exectue the command in argv[0]
*
* Returned Value:
* <0 If exec_namedapp() fails, then the negated errno value
* is returned.
* -1 (ERRROR) if the command was unsuccessful
* 0 (OK) if the command was successful
@@ -1439,13 +1439,13 @@ int nsh_parse(FAR struct nsh_vtbl_s *vtbl, char *cmdline)
}
/* Handle the case where the command is executed in background.
* However is app is to be started as namedapp new process will
* be created anyway, so skip this step. */
#ifndef CONFIG_NSH_DISABLEBG
if (vtbl->np.np_bg
#ifdef CONFIG_NSH_BUILTIN_APPS
- && namedapp_isavail(argv[0]) < 0
+ && builtin_isavail(argv[0]) < 0
#endif
)
{
@@ -726,7 +726,7 @@ static int cmd_exit(FAR struct nsh_vtbl_s *vtbl, int argc, char **argv)
*
* Returned Value:
- * <0 If exec_namedapp() fails, then the negated errno value
+ * <0 If exec_builtin() fails, then the negated errno value
* is returned.
* -1 (ERRROR) if the command was unsuccessful
@@ -1439,13 +1439,13 @@ int nsh_parse(FAR struct nsh_vtbl_s *vtbl, char *cmdline)
}
/* Handle the case where the command is executed in background.
- * However is app is to be started as namedapp new process will
+ * However is app is to be started as builtin new process will
* be created anyway, so skip this step. */
#ifndef CONFIG_NSH_DISABLEBG